@@ -3,7 +3,6 @@ import os
 from pathlib import Path
 from typing import Any, Dict, List, Optional
 
-import requests
 import uvicorn
 import yaml
 from fastapi import FastAPI, Request
@@ -11,6 +10,7 @@ from fastapi.middleware.cors import CORSMiddleware
 from fastapi.responses import StreamingResponse
 from pydantic import BaseModel, ValidationError
 
+from llmstudio.config import ENGINE_HOST, ENGINE_PORT
 from llmstudio.engine.providers import *
 
 ENGINE_BASE_ENDPOINT = "/api/engine"
@@ -18,13 +18,6 @@ ENGINE_HEALTH_ENDPOINT = "/health"
 ENGINE_TITLE = "LLMstudio Engine API"
 ENGINE_DESCRIPTION = "The core API for LLM interactions"
 ENGINE_VERSION = "0.1.0"
-ENGINE_HOST = os.getenv("ENGINE_HOST", "localhost")
-ENGINE_PORT = int(os.getenv("ENGINE_PORT", 8000))
-ENGINE_URL = f"http://{ENGINE_HOST}:{ENGINE_PORT}"
-UI_HOST = os.getenv("ENGINE_HOST", "localhost")
-UI_PORT = int(os.getenv("UI_PORT", 8000))
-UI_URL = f"http://{UI_HOST}:{UI_PORT}"
-LOG_LEVEL = os.getenv("LOG_LEVEL", "critical")
 
 
 # Models for Configuration
@@ -51,12 +44,31 @@ class EngineConfig(BaseModel):
 
 # Configuration Loading
 def _load_engine_config() -> EngineConfig:
-    config_path = Path(os.path.join(os.path.dirname(__file__), "config.yaml"))
+    default_config_path = Path(os.path.join(os.path.dirname(__file__), "config.yaml"))
+    local_config_path = Path(os.getcwd(), "config.yaml")
+
+    def _merge_configs(config1, config2):
+        for key in config2:
+            if key in config1:
+                if isinstance(config1[key], dict) and isinstance(config2[key], dict):
+                    _merge_configs(config1[key], config2[key])
+                elif isinstance(config1[key], list) and isinstance(config2[key], list):
+                    config1[key].extend(config2[key])
+                else:
+                    config1[key] = config2[key]
+            else:
+                config1[key] = config2[key]
+        return config1
+
     try:
-        config_data = yaml.safe_load(config_path.read_text())
+        default_config_data = yaml.safe_load(default_config_path.read_text())
+        local_config_data = (
+            yaml.safe_load(local_config_path.read_text())
+            if local_config_path.exists()
+            else {}
+        )
+        config_data = _merge_configs(default_config_data, local_config_data)
         return EngineConfig(**config_data)
-    except FileNotFoundError:
-        raise RuntimeError(f"Configuration file not found at {config_path}")
     except yaml.YAMLError as e:
         raise RuntimeError(f"Error parsing YAML configuration: {e}")
     except ValidationError as e:
@@ -73,7 +85,7 @@ def create_engine_app(config: EngineConfig = _load_engine_config()) -> FastAPI:
 
     app.add_middleware(
         CORSMiddleware,
-        allow_origins=["http://localhost:3000"],
+        allow_origins=["*"],
         allow_credentials=True,
         allow_methods=["*"],
         allow_headers=["*"],
@@ -121,6 +133,16 @@ def create_engine_app(config: EngineConfig = _load_engine_config()) -> FastAPI:
                 create_chat_handler(provider_config)
             )
 
+    @app.get(f"{ENGINE_BASE_ENDPOINT}/parameters")
+    def get_parameters(provider: str, model: Optional[str] = None):
+        """Return parameters for a given provider and model in an array JSON format."""
+        provider_config = config.providers.get(provider)
+        if not provider_config:
+            return {"error": f"Provider {provider} not found"}, 404
+        parameters = provider_config.parameters
+        parameters_array = [{"id": key, **value} for key, value in parameters.items()]
+        return parameters_array
+
     @app.post("/api/export")
     async def export(request: Request):
         data = await request.json()
@@ -138,25 +160,21 @@ def create_engine_app(config: EngineConfig = _load_engine_config()) -> FastAPI:
             iter([csv_content]), media_type="text/csv", headers=headers
         )
 
+    @app.on_event("startup")
+    async def startup_event():
+        print(f"Running LLMstudio Engine on http://{ENGINE_HOST}:{ENGINE_PORT} ")
+
     return app
 
 
-def is_api_running(url: str) -> bool:
-    try:
-        response = requests.get(url, timeout=5)
-        return response.status_code == 200
-    except requests.RequestException:
-        return False
-
-
 def run_engine_app():
-    print(f"Running Engine on {ENGINE_HOST}:{ENGINE_PORT}")
     try:
         engine = create_engine_app()
         uvicorn.run(
             engine,
             host=ENGINE_HOST,
             port=ENGINE_PORT,
+            log_level="warning",
         )
     except Exception as e:
-        print(f"Error running the Engine app: {e}")
+        print(f"Error running LLMstudio Engine: {e}")
