@@ -1,6 +1,6 @@
 import asyncio
 import os
-from typing import Any, AsyncGenerator, Coroutine, Generator, Optional
+from typing import Any, AsyncGenerator, Coroutine, Dict, Generator, List, Optional
 
 import openai
 from fastapi import HTTPException
@@ -12,7 +12,7 @@ from llmstudio.engine.providers.provider import ChatRequest, Provider, provider
 
 class OpenAIParameters(BaseModel):
     temperature: Optional[float] = Field(default=1, ge=0, le=2)
-    max_tokens: Optional[int] = Field(default=256, ge=1)
+    max_tokens: Optional[int] = Field(default=2048, ge=1)
     top_p: Optional[float] = Field(default=1, ge=0, le=1)
     frequency_penalty: Optional[float] = Field(default=0, ge=0, le=1)
     presence_penalty: Optional[float] = Field(default=0, ge=0, le=1)
@@ -20,6 +20,8 @@ class OpenAIParameters(BaseModel):
 
 class OpenAIRequest(ChatRequest):
     parameters: Optional[OpenAIParameters] = OpenAIParameters()
+    functions: Optional[List[Dict[str, Any]]] = None
+    chat_input: Any
 
 
 @provider
@@ -40,7 +42,13 @@ class OpenAIProvider(Provider):
             return await asyncio.to_thread(
                 client.chat.completions.create,
                 model=request.model,
-                messages=[{"role": "user", "content": request.chat_input}],
+                messages=(
+                    [{"role": "user", "content": request.chat_input}]
+                    if isinstance(request.chat_input, str)
+                    else request.chat_input
+                ),
+                functions=request.functions,
+                function_call="auto" if request.functions else None,
                 stream=True,
                 **request.parameters.model_dump(),
             )
@@ -48,8 +56,7 @@ class OpenAIProvider(Provider):
             raise HTTPException(status_code=e.status_code, detail=e.response.json())
 
     async def parse_response(
-        self, response: AsyncGenerator
+        self, response: AsyncGenerator, **kwargs
     ) -> AsyncGenerator[str, None]:
         for chunk in response:
-            if chunk.choices[0].finish_reason not in ["stop", "length"]:
-                yield chunk.choices[0].delta.content
+            yield chunk.model_dump()
